''' Mutable Primitives '''


class Mutable(object): # pylint: disable=useless-object-inheritance
    ''' Base class for mutable primitives '''
    def __init__(self, val, base):
        assert isinstance(val, base)
        self.base = base
        self.val = val

    def get(self):
        ''' get raw value of mutable '''
        return self.val

    def set(self, val):
        ''' set raw value of mutable '''
        self.val = val

    def __eq__(self, other):
        return self.val == other

    def __ne__(self, other):
        return self.val != other

    def __str__(self):
        return '{}({})'.format(self.__class__.__name__, self.val)

    def __repr__(self):
        return '{}({})'.format(self.__class__.__name__, self.val)



''' Bool - A mutable bool class

##################################################
###### AUTOGENERATED - DO NOT EDIT DIRECTLY ######
##################################################
'''

from mutable_primitives.base import Mutable


class Bool(Mutable):
    ''' Bool - A mutable bool class '''
    base = bool

    def __init__(self, val):
        super(Bool, self).__init__(val, self.base) #pylint: disable=super-with-arguments
        self.val = val

    def get(self):
        ''' get raw (primitive) value '''
        return self.val

    def set(self, val):
        ''' set raw (primitive) value '''
        assert isinstance(val, self.base)
        self.val = val

    def __eq__(self, other):
        return self.val == other

    def __ne__(self, other):
        return self.val != other

    def __str__(self):
        return '{}({})'.format(self.__class__.__name__, self.val)

    def __repr__(self):
        return '{}({})'.format(self.__class__.__name__, self.val)

    def __bool__(self):
        ''' boolean test for python3 '''
        if self.val:
            return True
        return False

    def __nonzero__(self):
        ''' boolean test for python2 '''
        if self.val:
            return True
        return False



''' Mutable Primitives Package '''
from mutable_primitives.base import Mutable
from mutable_primitives.bool import Bool
from mutable_primitives.int import Int
from mutable_primitives.float import Float



import os
from setuptools import setup, find_packages

HERE = os.path.dirname(os.path.realpath(__file__))

VERSION = '0.0.6'
PACKAGE_NAME = 'mutable_primitives'
AUTHOR = 'Dr. Nick'
AUTHOR_EMAIL = 'das-intensity@users.noreply.github.com'
URL = 'https://github.com/das-intensity/mutable-primitives'

LICENSE = 'MIT Licence'
DESCRIPTION = 'Mutable classes of python primitives'
LONG_DESCRIPTION = open(os.path.join(HERE, "README.md")).read()
LONG_DESC_TYPE = "text/markdown"

INSTALL_REQUIRES = [
]

setup(name=PACKAGE_NAME,
      version=VERSION,
      description=DESCRIPTION,
      long_description=LONG_DESCRIPTION,
      long_description_content_type=LONG_DESC_TYPE,
      author=AUTHOR,
      license=LICENSE,
      author_email=AUTHOR_EMAIL,
      url=URL,
      install_requires=INSTALL_REQUIRES,
      py_modules=['mutable_primitives'],
      classifiers=[
          'Programming Language :: Python :: 2',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.4',
          'Programming Language :: Python :: 3.5',
          'Programming Language :: Python :: 3.6',
          'Programming Language :: Python :: 3.7',
          'Programming Language :: Python :: 3.8',
          'Programming Language :: Python :: 3.9',
      ],
      packages=find_packages(),
      setup_requires=['pytest-runner'],
      tests_require=['pytest'],
      )



''' Float - A mutable float class

##################################################
###### AUTOGENERATED - DO NOT EDIT DIRECTLY ######
##################################################
'''

import sys
from mutable_primitives.base import Mutable


class Float(Mutable):
    ''' Float - A mutable float class '''
    base = float

    def __init__(self, val):
        super(Float, self).__init__(val, self.base) #pylint: disable=super-with-arguments
        self.val = val

    def get(self):
        ''' get raw (primitive) value '''
        return self.val

    def set(self, val):
        ''' set raw (primitive) value '''
        assert isinstance(val, self.base)
        self.val = val

    def __eq__(self, other):
        return self.val == other

    def __ne__(self, other):
        return self.val != other

    def __str__(self):
        return '{}({})'.format(self.__class__.__name__, self.val)

    def __repr__(self):
        return '{}({})'.format(self.__class__.__name__, self.val)

    def __bool__(self):
        ''' boolean test for python3 '''
        if self.val:
            return True
        return False

    def __nonzero__(self):
        ''' boolean test for python2 '''
        if self.val:
            return True
        return False

    def __add__(self, other):
        return self.val + other

    def __sub__(self, other):
        return self.val - other

    def __mul__(self, other):
        return self.val * other

    if sys.version_info[0] < 3:
        def __div__(self, other):
            return self.val / other
    else:
        def __floordiv__(self, other):
            return self.val // other

        def __truediv__(self, other):
            return self.val / other

    def __radd__(self, other):
        return other + self.val

    def __rsub__(self, other):
        return other - self.val

    def __rmul__(self, other):
        return other * self.val

    if sys.version_info[0] < 3:
        def __rdiv__(self, other):
            return other / self.val
    else:
        def __rfloordiv__(self, other):
            return other // self.val

        def __rtruediv__(self, other):
            return other / self.val

    def __iadd__(self, other):
        self.val += other
        return self

    def __isub__(self, other):
        self.val -= other
        return self

    def __imul__(self, other):
        self.val *= other
        return self

    if sys.version_info[0] < 3:
        def __idiv__(self, other):
            self.val /= other
            return self
    else:
        def __ifloordiv__(self, other):
            self.val //= other
            return self

        def __itruediv__(self, other):
            self.val /= other
            return self
